==> django_logging_requests-1.2.0-py3-none-any.whl: django_logging/middleware/logging.py <==
import traceback
import time
import json
import jwt

from django.http import HttpRequest
from django.conf import settings

from logging import getLogger


ERROR_LOGGER = getLogger('error_logger')
INFO_LOGGER = getLogger('info_logger')


class LoggingMiddleware:
    """Класс middleware который производит логирование всех запросов на endpoint и возникших ошибок."""

    def __init__(self, get_response):
        self.get_response = get_response

    def request_parse(self, http_request: HttpRequest) -> str:
        """Функция достает общую информацию из объекта запроса.

        Args:
            http_request (HttpRequest): Запрос, на основании которого будет сформировано сообщение;

        Returns:
            str: Сформированное сообщение для логов
        """

        def anonymize_token(token) -> str:
            if token is None:
                return 'Anonymous'
            return f'{token[:4]}....{token[-4:]}'

        def parse_token(token) -> str:
            user_id = 'Anonymous'
            token_version = 'Unknown'
            if token is not None:
                user_data = jwt.decode(token, options={"verify_signature": False}, algorithms=['HS256'])
                user_id = user_data.get('id')
                token_version = user_data.get('version')
            return f'\n\tUser id: {user_id};\n\tToken version: {token_version};'

        def is_json_body(request) -> bool:
            content_type = request.headers.get('Content-Type', None)
            return not hasattr(request, 'GET') and hasattr(request, 'body') and content_type == 'application/json'

        user_agent = http_request.headers.get('User_agent', None)
        ip = http_request.META.get('HTTP_X_FORWARDED_FOR', 'None')

        try:
            user_token = http_request.headers.get(settings.AUTHENTICATION_HEADER, None)
        except AttributeError:
            user_token = None

        body_info = ''
        if is_json_body(http_request):
            body_unicode = http_request.body.decode('utf-8')
            body = json.loads(body_unicode) if body_unicode else dict()
            for param_key in body:
                value = body[param_key]
                if isinstance(value, str) and len(value) > 100:
                    value = f'{value[0:99]}...'
                if param_key == 'password':
                    value = '********'
                body_info += f'\n\t\t{param_key}: {value}'

        if hasattr(http_request, 'GET'):
            query_params = dict(http_request.GET)
        else:
            query_params = dict()

        return (
            f'\n\tUser agent: {user_agent};'
            f'\n\tIP: {ip.split(",", 1)[0]};'
            f'\n\tToken: {anonymize_token(user_token)}'
            f'\n\tRequest: {http_request.path};'
            f'\n\tMethod: {http_request.method};'
            f'\n\tQuery params: {query_params};'
            f'\n\tContent type: {http_request.headers.get("Content-Type", None)};'
            f'\n\tBody: {body_info};'
            f'\n\tServer name: {settings.LOGGING_SERVER_NAME};'
            f'{parse_token(user_token)}'
        )

    def __call__(self, request):
        start_time = time.time()
        response = self.get_response(request)
        INFO_LOGGER.info(f'{self.request_parse(request)};\n\tExecution: {time.time() - start_time} seconds')

        return response

    def process_exception(self, request, exception):
        """Метод вызывается в случае ошибки внутри django view."""
        ERROR_LOGGER.error(f'{self.request_parse(request)}\n{traceback.format_exc().strip()};')

==> django_logging_requests-1.3.4-py3-none-any.whl: django_logging/middleware/logging.py <==
import traceback
import time
import json
import jwt

from django.http import HttpRequest
from django.conf import settings

from logging import getLogger


ERROR_LOGGER = getLogger('error_logger')
INFO_LOGGER = getLogger('info_logger')


class LoggingMiddleware:
    """Класс middleware который производит логирование всех запросов на endpoint и возникших ошибок."""

    def __init__(self, get_response):
        self.get_response = get_response

    def request_parse(self, http_request: HttpRequest) -> str:
        """Функция достает общую информацию из объекта запроса.

        Args:
            http_request (HttpRequest): Запрос, на основании которого будет сформировано сообщение;

        Returns:
            str: Сформированное сообщение для логов
        """

        def anonymize_token(token) -> str:
            if token is None:
                return 'Anonymous'
            return f'{token[:4]}....{token[-4:]}'

        def parse_token(token) -> str:
            user_id = 'Anonymous'
            token_version = 'Unknown'
            if token is not None:
                user_data = jwt.decode(token, options={"verify_signature": False}, algorithms=['HS256'])
                user_id = user_data.get('id')
                token_version = user_data.get('version')
            return f'\n\tUser id: {user_id};\n\tToken version: {token_version};'

        def is_json_body(request) -> bool:
            content_type = request.headers.get('Content-Type', None)
            return 'body' in request and content_type == 'application/json'

        user_agent = http_request.headers.get('User_agent', None)
        ip = http_request.META.get('HTTP_X_FORWARDED_FOR', 'None')

        try:
            user_token = http_request.headers.get(settings.AUTHENTICATION_HEADER, None)
        except AttributeError:
            user_token = None

        body_info = ''
        if is_json_body(http_request):
            body_unicode = http_request.body.decode('utf-8')
            body = json.loads(body_unicode) if body_unicode else dict()
            for param_key in body:
                value = body[param_key]
                if isinstance(value, str) and len(value) > 100:
                    value = f'{value[0:99]}...'
                if param_key == 'password':
                    value = '********'
                body_info += f'\n\t\t{param_key}: {value}'

        if hasattr(http_request, 'GET'):
            query_params = dict(http_request.GET)
        else:
            query_params = dict()

        return (
            f'\n\tUser agent: {user_agent};'
            f'\n\tIP: {ip.split(",", 1)[0]};'
            f'\n\tToken: {anonymize_token(user_token)}'
            f'\n\tRequest: {http_request.path};'
            f'\n\tMethod: {http_request.method};'
            f'\n\tQuery params: {query_params};'
            f'\n\tContent type: {http_request.headers.get("Content-Type", None)};'
            f'\n\tBody: {body_info};'
            f'\n\tServer name: {settings.LOGGING_SERVER_NAME};'
            f'{parse_token(user_token)}'
        )

    def __call__(self, request):
        start_time = time.time()
        response = self.get_response(request)
        if not settings.DEBUG:
            INFO_LOGGER.info(f'{self.request_parse(request)};\n\tExecution: {time.time() - start_time} seconds')

        return response

    def process_exception(self, request, exception):
        """Метод вызывается в случае ошибки внутри django view."""
        if not settings.DEBUG:
            ERROR_LOGGER.error(f'{self.request_parse(request)}\n{traceback.format_exc().strip()};')
